@@ -7,7 +7,7 @@
 	|	ae (another editor)					|
 	+---------------------------------------------------------------+
 
-	$Header: /home/hugh/sources/aee/RCS/aee.c,v 1.69 2001/02/27 04:11:37 hugh Exp $
+	$Header: /home/hugh/sources/aee/RCS/aee.c,v 1.78 2002/07/06 05:03:00 hugh Exp $
 
 */
 
@@ -48,7 +48,7 @@
  |	copyright.  All rights are reserved.
  |
  */
-char *copyright_notice = "Copyright (c) 1986 - 1988, 1991 - 2001 Hugh Mahon.";
+char *copyright_notice = "Copyright (c) 1986 - 1988, 1991 - 2002 Hugh Mahon.";
 
 char *long_notice[] = {
 	"This software and documentation contains", 
@@ -56,7 +56,9 @@ char *long_notice[] = {
 	"copyright.  All rights are reserved."
 	};
 
-char *version_string = "@(#) aee (another easy editor) version 2.2.7 February 2001 $Revision: 1.69 $";
+#include "aee_version.h"
+
+char *version_string = "@(#) aee (another easy editor) version "  AEE_VERSION  " " DATE_STRING " $Revision: 1.78 $";
 
 #include "aee.h"
 
@@ -162,6 +164,7 @@ char restricted = FALSE;	/* flag to indicate restricted mode	*/
 char com_win_initialized = FALSE;
 char text_only = TRUE;		/* editor is to treat file being read as 
 				   text only (not a binary file)	*/
+char ee_mode_menu = FALSE;	/* make main menu look more like ee's	*/
 
 long mask;			/* mask for sigblock			*/
 #ifdef XAE
@@ -398,6 +401,9 @@ struct menu_entries edit_menu[] = {
 	{NULL, NULL, NULL, NULL, NULL, -1}
 	};
 
+char *main_menu_strings[10];
+char *ee_mode_main_menu_strings[10];
+
 struct menu_entries main_menu[] = {
 	{"", NULL, NULL, NULL, NULL, 0}, 
 	{"", NULL, NULL, NULL, leave_op, -1}, 
@@ -426,8 +432,8 @@ struct menu_entries rae_err_menu[] = {
 	};
 
 
-char *commands[70];
-char *init_strings[40];
+char *commands[71];
+char *init_strings[41];
 
 /*
  |	memory debugging macros
@@ -507,6 +513,8 @@ char *info_help_msg;
 char *unix_text_msg, *dos_text_msg;
 char *text_cmd, *binary_cmd;
 char *text_msg, *binary_msg, *dos_msg, *unix_msg;
+char *DIFF_str;
+char *ee_mode_str;
 
 int 
 main(argc, argv)		/* beginning of main program		*/
@@ -523,6 +531,11 @@ char *argv[];
 /*
  |	The following code will start an xterm which will in turn execute 
  |	a debugger and "adopt" the process, so it can be debugged.
+ |
+ |	To compile to allow debug, use the command:
+ |
+ |		CFLAGS='-DDIAG_DBG -g' make
+ |
  */
 
 			int child_id;
@@ -534,6 +547,7 @@ char *argv[];
 				sprintf(command_line, 
 	      			"xterm -geom =80x40 -fg wheat -bg DarkSlateGrey -n %s -e gdb %s %d", 
 					"hello",  argv[0], child_id);
+				printf("command_line=%s\n", command_line);
 				execl("/bin/sh", "sh", "-c", command_line, NULL);
 				fprintf(stderr, "could not exec new window\n");
 				exit(1);
@@ -542,10 +556,10 @@ char *argv[];
 /*
  |	When in debugger, set child_id to zero (p child_id=0) to continue 
  |	executing the software.
+ */
 
 			while (child_id != 0)
 				;
- */
 			argc--;
 		}
 #endif
@@ -724,6 +738,8 @@ get_input(win_ptr)
 WINDOW *win_ptr;
 {
 	int value;
+	static int counter = 0;
+	pid_t parent_pid;
 
 	resize_check();
 
@@ -737,6 +753,28 @@ WINDOW *win_ptr;
 
 	if (in == EOF)		/* somehow lost contact with input	*/
 		abort_edit(0);
+
+#ifndef XAE
+	/*
+	 |	The above check used to work to detect if the parent 
+	 |	process died, but now it seems we need a more 
+	 |	sophisticated check.
+	 |
+	 |	Note that this check is only required for the terminal 
+	 |	version, and may be undesireable for xae, so is ifdef'd 
+	 |	accordingly.
+	 */
+	if (counter > 50)
+	{
+		parent_pid = getppid();
+		if (parent_pid == 1)
+			abort_edit(0);
+		else
+			counter = 0;
+	}
+	else
+		counter++;
+#endif /* !XAE */
 }
 
 void 
@@ -2677,6 +2715,41 @@ ae_init()	/* check for init file and read it if it exists	*/
 					observ_margins = TRUE;
 				else if (compare(str1, NOMARGINS_str,  FALSE))
 					observ_margins = FALSE;
+				else if (compare(str1, ee_mode_str,  FALSE))
+				{
+					ee_mode_menu = TRUE;
+					main_menu[0].item_string = ee_mode_main_menu_strings[0];
+					main_menu[1].item_string = ee_mode_main_menu_strings[1];
+					main_menu[2].item_string = ee_mode_main_menu_strings[2];
+					main_menu[3].item_string = ee_mode_main_menu_strings[3];
+					main_menu[4].item_string = ee_mode_main_menu_strings[4];
+					main_menu[5].item_string = ee_mode_main_menu_strings[5];
+					main_menu[6].item_string = ee_mode_main_menu_strings[6];
+					main_menu[7].item_string = ee_mode_main_menu_strings[7];
+					main_menu[8].item_string = ee_mode_main_menu_strings[8];
+					main_menu[3].procedure = menu_op;
+					main_menu[3].ptr_argument = file_menu;
+					main_menu[4].procedure = NULL;
+					main_menu[4].ptr_argument = NULL;
+					main_menu[4].iprocedure = NULL;
+					main_menu[4].nprocedure = redraw;
+					main_menu[5].procedure = NULL;
+					main_menu[5].ptr_argument = NULL;
+					main_menu[5].iprocedure = NULL;
+					main_menu[5].nprocedure = modes_op;
+					main_menu[6].procedure = menu_op;
+					main_menu[6].ptr_argument = search_menu;
+					main_menu[6].iprocedure = NULL;
+					main_menu[6].nprocedure = NULL;
+					main_menu[7].procedure = menu_op;
+					main_menu[7].ptr_argument = misc_menu;
+					main_menu[7].iprocedure = NULL;
+					main_menu[7].nprocedure = NULL;
+					main_menu[8].procedure = menu_op;
+					main_menu[8].ptr_argument = edit_menu;
+					main_menu[8].iprocedure = NULL;
+					main_menu[8].nprocedure = NULL;
+				}
 				else if ((compare(str1, LEFTMARGIN_str,  FALSE)) || (compare(str1, RIGHTMARGIN_str,  FALSE)))
 				{
 					tmp = next_word(str1);
