@@ -1,9 +1,9 @@
 /*
  |	aee.h
  |
- |	$Header: /home/hugh/sources/aee/RCS/aee.h,v 1.37 2000/01/19 04:47:54 hugh Exp $
+ |	$Header: /home/hugh/sources/aee/RCS/aee.h,v 1.42 2002/07/10 04:46:36 hugh Exp $
  |
- |	Copyright (c) 1986 - 1988, 1991 - 1996, 1999, 2000 Hugh Mahon.
+ |	Copyright (c) 1986 - 1988, 1991 - 1996, 1999, 2000, 2001 Hugh Mahon.
  |
  */
 
@@ -176,6 +176,8 @@ struct bufr {			/* structure for names of buffers	*/
 	char edit_buffer;	/* true if created as a result of edit cmd */
 	char dos_file;		/* true if file uses (or is to use) CR/LF 
 				   instead of just LF as line terminator   */
+	struct stat fileinfo;	/* information about the file obtained 
+				   using stat(2)			*/
 	};
 
 extern struct bufr *first_buff;	/* first buffer in list			*/
@@ -282,6 +284,7 @@ extern char restricted;		/* flag to indicate restricted mode	*/
 extern char com_win_initialized;
 extern char text_only;		/* editor is to treat file being read as 
 				   text only (not a binary file)	*/
+extern char ee_mode_menu; 	/* make main menu look more like ee's	*/
 
 #define CHAR_DELETED 1
 #define CHAR_BACKSPACE 2
@@ -430,6 +433,8 @@ extern struct menu_entries edit_menu[];
 extern struct menu_entries main_menu[];
 extern struct menu_entries del_buff_menu[];
 extern struct menu_entries rae_err_menu[];
+extern struct menu_entries file_being_edited_menu[];
+extern struct menu_entries file_modified_menu[];
 
 
 #define INFO_WIN_HEIGHT_DEF 6
@@ -441,8 +446,8 @@ extern struct menu_entries rae_err_menu[];
 #define CONTROL_KEYS 1
 #define COMMANDS     2
 
-extern char *commands[70];
-extern char *init_strings[40];
+extern char *commands[71];
+extern char *init_strings[41];
 
 /*
  |	memory debugging macros
@@ -527,10 +532,17 @@ extern char *info_help_msg;
 extern char *unix_text_msg, *dos_text_msg;
 extern char *text_cmd, *binary_cmd;
 extern char *text_msg, *binary_msg, *dos_msg, *unix_msg;
+extern char *file_being_edited_msg;
+extern char *file_modified_msg;
+extern char *DIFF_str;
+extern char *ee_mode_str;
 
 extern char *copyright_notice;
 extern char *version_string;
 
+extern char *main_menu_strings[10];
+extern char *ee_mode_main_menu_strings[10];
+
 /*
  |	Declare addresses for routines referenced in menus below.
  */
@@ -714,6 +726,7 @@ int del_buf P_((void));
 void redo_win P_((void));
 void resize_check P_((void));
 void set_up_term P_((void));
+void diff_file P_((void));
 
 #ifdef XAE
 void event_init P_((void));
