@@ -1,7 +1,7 @@
 /*
  |	control.c
  |
- |	$Header: /home/hugh/sources/aee/RCS/control.c,v 1.45 2001/02/16 03:54:51 hugh Exp hugh $
+ |	$Header: /home/hugh/sources/aee/RCS/control.c,v 1.48 2002/02/04 05:36:50 hugh Exp $
  */
 
 /*
@@ -647,7 +647,8 @@ int arg;
 	else if (arg == SAVE_FILE)
 	{
 	/*
-	 |	changes made here should be reflected in finish()
+	 |	changes made here should be reflected in finish() and 
+	 |	in command() where SAVE_str is handled.
 	 */
 
 		if (!curr_buff->edit_buffer)
@@ -703,7 +704,7 @@ int arg;
 			if (curr_buff->file_name == NULL)
 			{
 				curr_buff->full_name = get_full_path(string, 
-							curr_buff->orig_dir);
+							NULL);
 				curr_buff->file_name = 
 					ae_basename(curr_buff->full_name);
 			}
@@ -1119,7 +1120,51 @@ char *cmd_str;
 			free(cmd_str2);
 	}
 	else if (compare(cmd_str, SAVE_str, FALSE))
-		file_op(SAVE_FILE);
+	{
+		/*
+		 |	Should reflect changes made here in file_op() 
+		 |	where 'save' command is handled.
+		 */
+
+		cmd_str2 = next_word(cmd_str);
+		if (!curr_buff->edit_buffer)
+			file_op(SAVE_FILE);
+		else if ((*cmd_str2 != (char)NULL) && (curr_buff->file_name == NULL))
+		{
+			tmp_file = resolve_name(cmd_str2);
+			if (tmp_file != cmd_str2)
+			{
+				alloc_space = TRUE;
+				cmd_str2 = tmp_file;
+			}
+
+			if (write_file(cmd_str2))
+			{
+				if (curr_buff->file_name == NULL)
+				{
+					curr_buff->full_name = get_full_path(cmd_str2, 
+								NULL);
+					curr_buff->file_name = 
+						ae_basename(curr_buff->full_name);
+				}
+				curr_buff->changed = FALSE;
+				change = FALSE;
+				if (alloc_space)
+					free(cmd_str2);
+			}
+			else 
+			{
+				if (alloc_space)
+					free(cmd_str2);
+				return;
+			}
+		}
+		else
+		{
+			file_op(SAVE_FILE);
+		}
+
+	}
 	else if (compare(cmd_str, LITERAL_str, FALSE))
 		literal = TRUE;
 	else if (compare(cmd_str, NOLITERAL_str, FALSE))
@@ -1512,7 +1557,7 @@ char *cmd_str;
 	else if (compare(cmd_str, DELETE_str, FALSE))
 	{
 		if (!strncmp(curr_buff->name, main_buffer_name, 
-						strlen(main_buffer_name)))
+						strlen(curr_buff->name)))
 		{
 			wmove(com_win,0,0);
 			wclrtoeol(com_win);
@@ -1592,6 +1637,10 @@ char *cmd_str;
 	{
 		show_pwd();
 	}
+	else if (compare(cmd_str, DIFF_str, FALSE))
+	{
+		diff_file();
+	}
 	else
 	{
 		wmove(com_win,0,0);
@@ -2155,6 +2204,7 @@ dump_aee_conf()
 
 	wprintw(com_win, conf_dump_success_msg, file_name);
 	wrefresh(com_win);
+	clr_cmd_line = TRUE;
 
 	if ((option == 2) && (file_name != home_dir))
 	{
