@@ -4,7 +4,7 @@
  |		This file contains the routines for handling the journal file
  |		for ae.
  |
- |	$Header: /home/hugh/sources/aee/RCS/journal.c,v 1.35 2000/09/21 03:27:18 hugh Exp $
+ |	$Header: /home/hugh/sources/aee/RCS/journal.c,v 1.38 2002/07/10 04:36:25 hugh Exp hugh $
  */
 
 /*
@@ -67,7 +67,7 @@
  |
  */
 
-char *jrn_vers_str = "@(#)                           journal.c $Revision: 1.35 $";
+char *jrn_vers_str = "@(#)                           journal.c $Revision: 1.38 $";
 
 #include "aee.h"
 
@@ -292,7 +292,7 @@ char *file_name;
 	struct text *line;
 	char temp;
 	char done = FALSE;
-	char name[1024];
+	char name[1024]; /* name of file stored in journal file */
 
 	if ((buffer->journ_fd = open(file_name, O_RDONLY)) == -1)
 	{
@@ -377,15 +377,13 @@ char *file_name;
 
 	if ((buffer->full_name == NULL) || (*buffer->full_name == (char) NULL))
 	{
-		buffer->full_name = (name[0] == (char) NULL) ? NULL : strdup(name);
-		if (buffer->full_name != NULL)
+		buffer->full_name = strdup(name);
+		if ((buffer->full_name != NULL) && (*buffer->full_name != (char) NULL))
 		{
 			buffer->file_name = ae_basename(buffer->full_name);
 			if (strcmp(main_buffer_name, buffer->name))
 				buffer->name = strdup(buffer->file_name);
 		}
-		else
-			buffer->file_name = NULL;
 	}
 
 	/*
@@ -642,7 +640,8 @@ struct bufr *buffer;
 	}
 	else
 	{
-		while (((list->next != NULL) && 
+		while (((list->next != NULL) && (buffer->journal_file != NULL) && 
+		      (buffer->full_name != NULL) &&
 		      (!((list->next->file_name != NULL) && 
 			    (!strcmp(buffer->full_name, list->next->file_name) 
 		 && !strcmp(buffer->journal_file, list->next->journal_name)))))
@@ -723,7 +722,22 @@ char *file_name;
 	int count;
 
 	if (*file_name == (char)NULL)
-		file_name = "no_file_journal";
+	{
+		struct tm *time_info;
+		time_t t;
+		int ret_val;
+
+		/*
+		 |	create a file name based on the date, e.g., 
+		 |	950913221206.rv
+		 |	Not a guarantee of uniqueness, but certainly not 
+		 |	likely to be repeated.
+		 */
+		file_name = (char *)malloc(14);
+		t = time(NULL);
+		time_info = gmtime(&t);
+		ret_val = strftime(file_name, 13, "%y%m%d%H%M%S", time_info);
+	}
 
 	if ((journal_dir != NULL) && (*journal_dir != (char) NULL))
 	{
