@@ -1,7 +1,7 @@
 /*
  |	srch_rep.c
  |
- |	$Header: /home/hugh/sources/aee/RCS/srch_rep.c,v 1.7 1996/12/01 23:07:50 hugh Exp hugh $
+ |	$Header: /home/hugh/sources/aee/RCS/srch_rep.c,v 1.8 2002/02/04 05:37:57 hugh Exp $
  */
 
 /*
@@ -322,6 +322,8 @@ int disp;		/* boolean for whether or not to display message */
 			{
 				wmove(com_win, 0, 0);
 				wclrtoeol(com_win);
+				clr_cmd_line = FALSE;
+				status_display();
 				wrefresh(com_win);
 			}
 			if (lines_moved != 0)
